import { defineStore } from 'pinia'
import { ref } from 'vue'
import axios from 'axios'
import { useRouter } from 'vue-router'

export const useAuthStore = defineStore('auth', () => {
  const user = ref(null)
  const router = useRouter()

  // 登录
  const login = async (username, password) => {
    const response = await axios.post('/api/login', {
      username,
      password
    })
    user.value = response.data.user
    localStorage.setItem('token', response.data.token)
    router.push('/user/dashboard')
  }

  // 登出
  const logout = () => {
    user.value = null
    localStorage.removeItem('token')
    router.push('/login')
  }

  // 检查登录状态
  const checkAuth = async () => {
    try {
      const response = await axios.get('/api/user/me')
      user.value = response.data
    } catch (error) {
      logout()
    }
  }

  return {
    user,
    login,
    logout,
    checkAuth
  }
})